@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """API models package."""
-from . import discover, meta, nodes, roles, settings, system, users
+from . import (central_core, discover, meta, nodes, roles, settings, system,
+               users)
 from .system import System
 
 __all__ = (
@@ -12,4 +13,5 @@ __all__ = (
     "roles",
     "settings",
     "users",
+    "central_core",
 )
